@@ -2,7 +2,7 @@
 from typing import NoReturn
 
 from botx.clients.methods.base import BotXMethod
-from botx.clients.methods.wrappers import HTTPResponse
+from botx.clients.types.http import HTTPResponse
 from botx.exceptions import BotXAPIError
 
 
