@@ -1,9 +1,8 @@
 """Method for enabling stealth in chat."""
+from http import HTTPStatus
 from typing import Optional
 from uuid import UUID
 
-import httpx
-
 from botx.clients.methods.base import AuthorizedBotXMethod
 from botx.clients.methods.errors import bot_is_not_admin, chat_not_found
 
@@ -15,8 +14,8 @@ class StealthSet(AuthorizedBotXMethod[bool]):
     __method__ = "POST"
     __returning__ = bool
     __errors_handlers__ = {
-        httpx.codes.FORBIDDEN: bot_is_not_admin.handle_error,
-        httpx.codes.NOT_FOUND: chat_not_found.handle_error,
+        HTTPStatus.FORBIDDEN: bot_is_not_admin.handle_error,
+        HTTPStatus.NOT_FOUND: chat_not_found.handle_error,
     }
 
     #: ID of chat where stealth should be enabled.
