@@ -42,7 +42,9 @@ class DependencyFailure(BotXException):
 class BotXAPIError(BotXException):
     """Raised if there is an error in requests to BotX API."""
 
-    message_template = "unable to send {method} {url} to BotX API ({status})"
+    message_template = (
+        "unable to send {method} {url} to BotX API ({status}): {response_content}"
+    )
 
     #: URL from request.
     url: str
